@@ -5,7 +5,7 @@
 #' It is inspired by [datamodelr](https://github.com/bergant/datamodelr),
 #' and extends the idea by offering operations to access the data in the tables.
 #'
-#' `dm()` creates a `dm` object from one or multiple [tbl] objects
+#' `dm()` creates a `dm` object from [tbl] objects
 #' (tibbles or lazy data objects).
 #'
 #' @param ... Tables to add to the `dm` object.
@@ -451,12 +451,22 @@ format.dm <- function(x, ...) {
 
 #' @export
 print.dm <- function(x, ...) {
-  cat_rule("Table source", col = "green")
+  show_dm(x)
+  invisible(x)
+}
+
+show_dm <- function(x) {
   def <- dm_get_def(x)
+  if (nrow(def) == 0) {
+    cat_line("dm()")
+    return()
+  }
+
+  cat_rule("Table source", col = "green")
   src <- dm_get_src(x)
   db_info <- NULL
 
-  if (!is.null(src$con) && nrow(def) >= 0) {
+  if (!is.null(src$con)) {
     # FIXME: change to pillar::tbl_sum() once it's there
     tbl_str <- tibble::tbl_sum(def$data[[1]])
     if ("Database" %in% names(tbl_str)) {
@@ -481,8 +491,6 @@ print.dm <- function(x, ...) {
     cat_rule("Filters", col = "orange")
     walk2(filters$table, filters$filter, ~ cat_line(paste0(.x, ": ", as_label(.y))))
   }
-
-  invisible(x)
 }
 
 def_get_n_tables <- function(def) {
@@ -558,7 +566,7 @@ format.zoomed_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 
 #' @export
 `$.dm` <- function(x, name) {
-  table <- as_string(ensym(name))
+  table <- dm_tbl_name(x, {{ name }})
   tbl(x, table)
 }
 
@@ -659,7 +667,7 @@ tbl.dm <- function(src, from, ...) {
   # The src argument here is a dm object
   dm <- src
   check_not_zoomed(dm)
-  check_correct_input(dm, from, 1L)
+  from <- dm_tbl_name(dm, !!from)
 
   dm_get_tables_impl(dm)[[from]]
 }
