@@ -50,16 +50,6 @@ error_txt_not_unique_key <- function(table_name, column_names) {
   glue("({commas(tick(column_names))}) not a unique key of {tick(table_name)}.")
 }
 
-# general error: table not part of `dm` -----------------------------------
-
-abort_table_not_in_dm <- function(table_name, dm_tables) {
-  abort(error_txt_table_not_in_dm(table_name, dm_tables), .subclass = dm_error_full("table_not_in_dm"))
-}
-
-error_txt_table_not_in_dm <- function(table_name, dm_tables) {
-  glue("Table(s) {commas(tick(table_name))} not in `dm` object. Available table names: {commas(tick(dm_tables))}.")
-}
-
 # error: is not subset of -------------------------------------------------
 
 abort_not_subset_of <- function(table_name_1, colname_1,
@@ -231,17 +221,6 @@ error_txt_no_unique_indexes <- function() {
   "`copy_dm_to()` does not support the `unique_indexes` argument."
 }
 
-abort_need_named_vec <- function(table_names) {
-  abort(error_txt_need_named_vec(table_names), .subclass = dm_error_full("need_named_vec"))
-}
-
-error_txt_need_named_vec <- function(table_names) {
-  glue(
-    "Parameter `table_names` in `copy_dm_to()` needs to be a named vector whose names ",
-    "are the original table names (returned by e.g. `src_tbls()`): {commas(tick(table_names))}."
-  )
-}
-
 abort_key_constraints_need_db <- function() {
   abort(error_txt_key_constraints_need_db(), .subclass = dm_error_full("key_constraints_need_db"))
 }
@@ -356,16 +335,6 @@ error_txt_no_flatten_with_nest_join <- function() {
   )
 }
 
-# either explicit table names, or auto-unique ones ------------------------
-
-abort_unique_table_names_or_table_names <- function() {
-  abort(error_txt_unique_table_names_or_table_names(), .subclass = dm_error_full("unique_table_names_or_table_names"))
-}
-
-error_txt_unique_table_names_or_table_names <- function() {
-  "Can supply either `table_names` or `unique_table_names = TRUE`, not both."
-}
-
 
 # object is not a `dm` (but should be one) --------------------------------
 abort_is_not_dm <- function(obj_class) {
