@@ -55,9 +55,8 @@
 #'   dm_draw()
 dm_add_fk <- function(dm, table, columns, ref_table, check = FALSE) {
   check_not_zoomed(dm)
-  table_name <- as_name(ensym(table))
-  ref_table_name <- as_name(ensym(ref_table))
-  check_correct_input(dm, c(table_name, ref_table_name), 2L)
+  table_name <- dm_tbl_name(dm, {{ table }})
+  ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
 
   column_name <- as_name(ensym(columns))
   check_col_input(dm, table_name, column_name)
@@ -124,7 +123,9 @@ dm_add_fk_impl <- function(dm, table, column, ref_table) {
 #'   dm_has_fk(airports, flights)
 dm_has_fk <- function(dm, table, ref_table) {
   check_not_zoomed(dm)
-  dm_has_fk_impl(dm, as_name(ensym(table)), as_name(ensym(ref_table)))
+  table_name <- dm_tbl_name(dm, {{ table }})
+  ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
+  dm_has_fk_impl(dm, table_name, ref_table_name)
 }
 
 dm_has_fk_impl <- function(dm, table_name, ref_table_name) {
@@ -160,15 +161,13 @@ dm_has_fk_impl <- function(dm, table_name, ref_table_name) {
 dm_get_fk <- function(dm, table, ref_table) {
   check_not_zoomed(dm)
 
-  table_name <- as_name(ensym(table))
-  ref_table_name <- as_name(ensym(ref_table))
+  table_name <- dm_tbl_name(dm, {{ table }})
+  ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
 
   new_keys(dm_get_fk_impl(dm, table_name, ref_table_name))
 }
 
 dm_get_fk_impl <- function(dm, table_name, ref_table_name) {
-  check_correct_input(dm, c(table_name, ref_table_name), 2L)
-
   fks <- dm_get_data_model_fks(dm)
   fks$column[fks$table == table_name & fks$ref == ref_table_name]
 }
@@ -234,10 +233,8 @@ dm_rm_fk <- function(dm, table, columns, ref_table) {
   if (quo_is_missing(column_quo)) {
     abort_rm_fk_col_missing()
   }
-  table_name <- as_name(ensym(table))
-  ref_table_name <- as_name(ensym(ref_table))
-
-  check_correct_input(dm, c(table_name, ref_table_name), 2L)
+  table_name <- dm_tbl_name(dm, {{ table }})
+  ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
 
   fk_cols <- dm_get_fk_impl(dm, table_name, ref_table_name)
   if (is_empty(fk_cols)) {
@@ -328,10 +325,8 @@ dm_enum_fk_candidates <- function(dm, table, ref_table) {
   # FIXME: with "direct" filter maybe no check necessary: but do we want to check
   # for tables retrieved with `tbl()` or with `dm_get_tables()[[table_name]]`
   check_no_filter(dm)
-  table_name <- as_string(ensym(table))
-  ref_table_name <- as_string(ensym(ref_table))
-
-  check_correct_input(dm, c(table_name, ref_table_name), 2L)
+  table_name <- dm_tbl_name(dm, {{ table }})
+  ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
 
   ref_tbl_pk <- dm_get_pk_impl(dm, ref_table_name)
 
@@ -353,8 +348,7 @@ enum_fk_candidates <- function(zoomed_dm, ref_table) {
   check_no_filter(zoomed_dm)
 
   table_name <- orig_name_zoomed(zoomed_dm)
-  ref_table_name <- as_string(ensym(ref_table))
-  check_correct_input(zoomed_dm, ref_table_name)
+  ref_table_name <- dm_tbl_name(zoomed_dm, {{ ref_table }})
 
   ref_tbl_pk <- dm_get_pk_impl(zoomed_dm, ref_table_name)
 
