@@ -3,17 +3,17 @@ test_src_df <- function() {
 }
 
 test_src_sqlite <- function() {
-  src_dbi(DBI::dbConnect(RSQLite::SQLite(), ":memory:"), auto_disconnect = TRUE)
+  dbplyr::src_dbi(DBI::dbConnect(RSQLite::SQLite(), ":memory:"), auto_disconnect = TRUE)
 }
 
 test_src_postgres <- function() {
   con <- DBI::dbConnect(RPostgres::Postgres())
-  src_dbi(con, auto_disconnect = TRUE)
+  dbplyr::src_dbi(con, auto_disconnect = TRUE)
 }
 
 test_src_maria <- function() {
   con <- DBI::dbConnect(RMariaDB::MariaDB(), dbname = "test")
-  src_dbi(con, auto_disconnect = TRUE)
+  dbplyr::src_dbi(con, auto_disconnect = TRUE)
 }
 
 test_src_mssql <- function() {
@@ -22,5 +22,5 @@ test_src_mssql <- function() {
     "mssql-test",
     uid = "kirill", pwd = keyring::key_get("mssql", "kirill")
   )
-  src_dbi(con, auto_disconnect = TRUE)
+  dbplyr::src_dbi(con, auto_disconnect = TRUE)
 }
