@@ -14,8 +14,6 @@ test_that("API", {
 })
 
 test_that("`dm_set_colors()` works", {
-  skip_if_remote_src()
-
   expect_identical(
     dm_set_colors(
       dm_nycflights_small(),
@@ -46,8 +44,6 @@ test_that("`dm_set_colors()` works", {
 })
 
 test_that("`dm_set_colors()` errors if old syntax used", {
-  skip_if_remote_src()
-
   expect_dm_error(
     dm_set_colors(
       dm_nycflights_small(),
@@ -62,7 +58,6 @@ test_that("`dm_set_colors()` errors if old syntax used", {
 
 test_that("`dm_set_colors()` errors with unnamed args", {
   skip_if_src("postgres")
-  skip_if_src("mssql")
 
   expect_dm_error(
     dm_set_colors(
@@ -85,7 +80,6 @@ test_that("last", {
 
 test_that("bad color", {
   skip_if_not(getRversion() >= "3.5")
-  skip_if_remote_src()
 
   expect_dm_error(
     dm_set_colors(
@@ -98,7 +92,6 @@ test_that("bad color", {
 
 test_that("getter", {
   skip_if_src("postgres")
-  skip_if_src("mssql")
   expect_equal(
     dm_get_colors(dm_nycflights13()),
     c(
@@ -157,7 +150,6 @@ test_that("helpers", {
 })
 
 test_that("output", {
-  skip_if_remote_src()
   expect_known_output(
     dm_nycflights13() %>%
       dm_draw() %>%
