@@ -12,11 +12,6 @@ nyc_check <- tibble::tribble(
 
 test_that("`dm_examine_constraints()` works", {
 
-  # FIXME: remove after 15 May 2020 (dplyr update)?
-  if (packageVersion("dbplyr") >= "1.4.3" && packageVersion("dplyr") < "0.8.99") {
-    skip("slight package incompatibility")
-  }
-
   # case of no constraints:
   expect_identical(
     dm_examine_constraints(dm_test_obj()),
